#!/usr/bin/env python
#
# Data Quality Checker also known as DQC
#
# Read the README.md for more detailed information
#
#       Barcelona Supercomputing Center - Centro Nacional de Supercomputacion
#       Earth Sciences Department - Computational Earth Sciences
#     
#     Authors: 
#       Joan Sala Calero (joan.sala@bsc.es)
#

from dqc_wrapper.utils.utils_pdf import *
from dqc_wrapper.utils.utils_files import *

def read_conf_file(res_file):
	config = configparser.ConfigParser()
	config.read(res_file)
	return config

def get_log_file(log_folder, res_file):
	# Get latest available log file
	log_files = sorted(
		glob.glob(os.path.join(log_folder, 'LOG_{}*.txt'.format(os.path.basename(res_file)))),
		reverse=True,
	)
	return log_files[0]

def ini2pdf(res_file, log_file):

	# Res file  
	config = read_conf_file(res_file)

	# Save PDF report (result + log)
	if os.path.exists(log_file):
		for s in config.sections():
			if not('result' in s):
				save_pdf_report(s, res_file, log_file)
	else:
		print('ERROR: Missing log file {}'.format(log_file))


'''
Script in order to convert res and log files to separate PDFs to be imported at the CDS / CMS
'''

# Folder with results
res_folder = '/shared/QAR_dqc/results'
log_folder = '/shared/QAR_dqc/logs'

for res_file in glob.glob(os.path.join(res_folder, '*.ini')):
	print('------------------------')
	print(res_file)

	log_file = os.path.join(log_folder, get_log_file(log_folder, res_file))
	print(log_file)

	ini2pdf(res_file, log_file)
